==> zio-aws-ssm_3-5.17.225.1-sources.jar: zio/aws/ssm/model/UpdateMaintenanceWindowTaskRequest.scala <==
package zio.aws.ssm.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTaskParameterName,
  MaintenanceWindowTaskPriority,
  MaintenanceWindowId,
  MaintenanceWindowTaskArn,
  MaintenanceWindowTaskId,
  ServiceRole,
  MaxConcurrency,
  MaintenanceWindowName,
  MaxErrors,
  MaintenanceWindowDescription
}
import scala.jdk.CollectionConverters.*
final case class UpdateMaintenanceWindowTaskRequest(
    windowId: MaintenanceWindowId,
    windowTaskId: MaintenanceWindowTaskId,
    targets: Optional[Iterable[zio.aws.ssm.model.Target]] = Optional.Absent,
    taskArn: Optional[MaintenanceWindowTaskArn] = Optional.Absent,
    serviceRoleArn: Optional[ServiceRole] = Optional.Absent,
    taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression
    ]] = Optional.Absent,
    taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters
    ] = Optional.Absent,
    priority: Optional[MaintenanceWindowTaskPriority] = Optional.Absent,
    maxConcurrency: Optional[MaxConcurrency] = Optional.Absent,
    maxErrors: Optional[MaxErrors] = Optional.Absent,
    loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo] = Optional.Absent,
    name: Optional[MaintenanceWindowName] = Optional.Absent,
    description: Optional[MaintenanceWindowDescription] = Optional.Absent,
    replace: Optional[Boolean] = Optional.Absent,
    cutoffBehavior: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest = {
    import UpdateMaintenanceWindowTaskRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
      .builder()
      .windowId(MaintenanceWindowId.unwrap(windowId): java.lang.String)
      .windowTaskId(
        MaintenanceWindowTaskId.unwrap(windowTaskId): java.lang.String
      )
      .optionallyWith(
        targets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.targets)
      .optionallyWith(
        taskArn.map(value =>
          MaintenanceWindowTaskArn.unwrap(value): java.lang.String
        )
      )(_.taskArn)
      .optionallyWith(
        serviceRoleArn.map(value => ServiceRole.unwrap(value): java.lang.String)
      )(_.serviceRoleArn)
      .optionallyWith(
        taskParameters.map(value =>
          value
            .map({ case (key, value) =>
              (MaintenanceWindowTaskParameterName.unwrap(
                key
              ): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.taskParameters)
      .optionallyWith(
        taskInvocationParameters.map(value => value.buildAwsValue())
      )(_.taskInvocationParameters)
      .optionallyWith(
        priority.map(value =>
          MaintenanceWindowTaskPriority.unwrap(value): Integer
        )
      )(_.priority)
      .optionallyWith(
        maxConcurrency.map(value =>
          MaxConcurrency.unwrap(value): java.lang.String
        )
      )(_.maxConcurrency)
      .optionallyWith(
        maxErrors.map(value => MaxErrors.unwrap(value): java.lang.String)
      )(_.maxErrors)
      .optionallyWith(loggingInfo.map(value => value.buildAwsValue()))(
        _.loggingInfo
      )
      .optionallyWith(
        name.map(value => MaintenanceWindowName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          MaintenanceWindowDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(replace.map(value => value: java.lang.Boolean))(_.replace)
      .optionallyWith(cutoffBehavior.map(value => value.unwrap))(
        _.cutoffBehavior
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly =
    zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.wrap(buildAwsValue())
}
object UpdateMaintenanceWindowTaskRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest =
      zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest(
        windowId,
        windowTaskId,
        targets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        taskArn.map(value => value),
        serviceRoleArn.map(value => value),
        taskParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        taskInvocationParameters.map(value => value.asEditable),
        priority.map(value => value),
        maxConcurrency.map(value => value),
        maxErrors.map(value => value),
        loggingInfo.map(value => value.asEditable),
        name.map(value => value),
        description.map(value => value),
        replace.map(value => value),
        cutoffBehavior.map(value => value)
      )
    def windowId: MaintenanceWindowId
    def windowTaskId: MaintenanceWindowTaskId
    def targets: Optional[List[zio.aws.ssm.model.Target.ReadOnly]]
    def taskArn: Optional[MaintenanceWindowTaskArn]
    def serviceRoleArn: Optional[ServiceRole]
    def taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]]
    def taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ]
    def priority: Optional[MaintenanceWindowTaskPriority]
    def maxConcurrency: Optional[MaxConcurrency]
    def maxErrors: Optional[MaxErrors]
    def loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo.ReadOnly]
    def name: Optional[MaintenanceWindowName]
    def description: Optional[MaintenanceWindowDescription]
    def replace: Optional[Boolean]
    def cutoffBehavior
        : Optional[zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior]
    def getWindowId: ZIO[Any, Nothing, MaintenanceWindowId] =
      ZIO.succeed(windowId)
    def getWindowTaskId: ZIO[Any, Nothing, MaintenanceWindowTaskId] =
      ZIO.succeed(windowTaskId)
    def getTargets
        : ZIO[Any, AwsError, List[zio.aws.ssm.model.Target.ReadOnly]] =
      AwsError.unwrapOptionField("targets", targets)
    def getTaskArn: ZIO[Any, AwsError, MaintenanceWindowTaskArn] =
      AwsError.unwrapOptionField("taskArn", taskArn)
    def getServiceRoleArn: ZIO[Any, AwsError, ServiceRole] =
      AwsError.unwrapOptionField("serviceRoleArn", serviceRoleArn)
    def getTaskParameters: ZIO[Any, AwsError, Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]] = AwsError.unwrapOptionField("taskParameters", taskParameters)
    def getTaskInvocationParameters: ZIO[
      Any,
      AwsError,
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ] = AwsError.unwrapOptionField(
      "taskInvocationParameters",
      taskInvocationParameters
    )
    def getPriority: ZIO[Any, AwsError, MaintenanceWindowTaskPriority] =
      AwsError.unwrapOptionField("priority", priority)
    def getMaxConcurrency: ZIO[Any, AwsError, MaxConcurrency] =
      AwsError.unwrapOptionField("maxConcurrency", maxConcurrency)
    def getMaxErrors: ZIO[Any, AwsError, MaxErrors] =
      AwsError.unwrapOptionField("maxErrors", maxErrors)
    def getLoggingInfo
        : ZIO[Any, AwsError, zio.aws.ssm.model.LoggingInfo.ReadOnly] =
      AwsError.unwrapOptionField("loggingInfo", loggingInfo)
    def getName: ZIO[Any, AwsError, MaintenanceWindowName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, MaintenanceWindowDescription] =
      AwsError.unwrapOptionField("description", description)
    def getReplace: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("replace", replace)
    def getCutoffBehavior: ZIO[
      Any,
      AwsError,
      zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior
    ] = AwsError.unwrapOptionField("cutoffBehavior", cutoffBehavior)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ) extends zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly {
    override val windowId: MaintenanceWindowId =
      zio.aws.ssm.model.primitives.MaintenanceWindowId(impl.windowId())
    override val windowTaskId: MaintenanceWindowTaskId =
      zio.aws.ssm.model.primitives.MaintenanceWindowTaskId(impl.windowTaskId())
    override val targets: Optional[List[zio.aws.ssm.model.Target.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.Target.wrap(item)
          }.toList
        )
    override val taskArn: Optional[MaintenanceWindowTaskArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.taskArn())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowTaskArn(value)
        )
    override val serviceRoleArn: Optional[ServiceRole] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceRoleArn())
      .map(value => zio.aws.ssm.model.primitives.ServiceRole(value))
    override val taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.taskParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.ssm.model.primitives.MaintenanceWindowTaskParameterName(
              key
            ) -> zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression
              .wrap(value)
          })
          .toMap
      )
    override val taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.taskInvocationParameters())
      .map(value =>
        zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.wrap(value)
      )
    override val priority: Optional[MaintenanceWindowTaskPriority] =
      zio.aws.core.internal
        .optionalFromNullable(impl.priority())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowTaskPriority(value)
        )
    override val maxConcurrency: Optional[MaxConcurrency] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxConcurrency())
        .map(value => zio.aws.ssm.model.primitives.MaxConcurrency(value))
    override val maxErrors: Optional[MaxErrors] = zio.aws.core.internal
      .optionalFromNullable(impl.maxErrors())
      .map(value => zio.aws.ssm.model.primitives.MaxErrors(value))
    override val loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loggingInfo())
        .map(value => zio.aws.ssm.model.LoggingInfo.wrap(value))
    override val name: Optional[MaintenanceWindowName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.ssm.model.primitives.MaintenanceWindowName(value))
    override val description: Optional[MaintenanceWindowDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowDescription(value)
        )
    override val replace: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.replace())
      .map(value => value: Boolean)
    override val cutoffBehavior
        : Optional[zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cutoffBehavior())
        .map(value =>
          zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ): zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssm_3-7.21.15.1-sources.jar: zio/aws/ssm/model/UpdateMaintenanceWindowTaskRequest.scala <==
package zio.aws.ssm.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTaskParameterName,
  MaintenanceWindowTaskPriority,
  MaintenanceWindowId,
  MaintenanceWindowTaskArn,
  MaintenanceWindowTaskId,
  ServiceRole,
  MaxConcurrency,
  MaintenanceWindowName,
  MaxErrors,
  MaintenanceWindowDescription
}
import scala.jdk.CollectionConverters.*
final case class UpdateMaintenanceWindowTaskRequest(
    windowId: MaintenanceWindowId,
    windowTaskId: MaintenanceWindowTaskId,
    targets: Optional[Iterable[zio.aws.ssm.model.Target]] = Optional.Absent,
    taskArn: Optional[MaintenanceWindowTaskArn] = Optional.Absent,
    serviceRoleArn: Optional[ServiceRole] = Optional.Absent,
    taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression
    ]] = Optional.Absent,
    taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters
    ] = Optional.Absent,
    priority: Optional[MaintenanceWindowTaskPriority] = Optional.Absent,
    maxConcurrency: Optional[MaxConcurrency] = Optional.Absent,
    maxErrors: Optional[MaxErrors] = Optional.Absent,
    loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo] = Optional.Absent,
    name: Optional[MaintenanceWindowName] = Optional.Absent,
    description: Optional[MaintenanceWindowDescription] = Optional.Absent,
    replace: Optional[Boolean] = Optional.Absent,
    cutoffBehavior: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior
    ] = Optional.Absent,
    alarmConfiguration: Optional[zio.aws.ssm.model.AlarmConfiguration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest = {
    import UpdateMaintenanceWindowTaskRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
      .builder()
      .windowId(MaintenanceWindowId.unwrap(windowId): java.lang.String)
      .windowTaskId(
        MaintenanceWindowTaskId.unwrap(windowTaskId): java.lang.String
      )
      .optionallyWith(
        targets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.targets)
      .optionallyWith(
        taskArn.map(value =>
          MaintenanceWindowTaskArn.unwrap(value): java.lang.String
        )
      )(_.taskArn)
      .optionallyWith(
        serviceRoleArn.map(value => ServiceRole.unwrap(value): java.lang.String)
      )(_.serviceRoleArn)
      .optionallyWith(
        taskParameters.map(value =>
          value
            .map({ case (key, value) =>
              (MaintenanceWindowTaskParameterName.unwrap(
                key
              ): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.taskParameters)
      .optionallyWith(
        taskInvocationParameters.map(value => value.buildAwsValue())
      )(_.taskInvocationParameters)
      .optionallyWith(
        priority.map(value =>
          MaintenanceWindowTaskPriority.unwrap(value): Integer
        )
      )(_.priority)
      .optionallyWith(
        maxConcurrency.map(value =>
          MaxConcurrency.unwrap(value): java.lang.String
        )
      )(_.maxConcurrency)
      .optionallyWith(
        maxErrors.map(value => MaxErrors.unwrap(value): java.lang.String)
      )(_.maxErrors)
      .optionallyWith(loggingInfo.map(value => value.buildAwsValue()))(
        _.loggingInfo
      )
      .optionallyWith(
        name.map(value => MaintenanceWindowName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          MaintenanceWindowDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(replace.map(value => value: java.lang.Boolean))(_.replace)
      .optionallyWith(cutoffBehavior.map(value => value.unwrap))(
        _.cutoffBehavior
      )
      .optionallyWith(alarmConfiguration.map(value => value.buildAwsValue()))(
        _.alarmConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly =
    zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.wrap(buildAwsValue())
}
object UpdateMaintenanceWindowTaskRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest =
      zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest(
        windowId,
        windowTaskId,
        targets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        taskArn.map(value => value),
        serviceRoleArn.map(value => value),
        taskParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        taskInvocationParameters.map(value => value.asEditable),
        priority.map(value => value),
        maxConcurrency.map(value => value),
        maxErrors.map(value => value),
        loggingInfo.map(value => value.asEditable),
        name.map(value => value),
        description.map(value => value),
        replace.map(value => value),
        cutoffBehavior.map(value => value),
        alarmConfiguration.map(value => value.asEditable)
      )
    def windowId: MaintenanceWindowId
    def windowTaskId: MaintenanceWindowTaskId
    def targets: Optional[List[zio.aws.ssm.model.Target.ReadOnly]]
    def taskArn: Optional[MaintenanceWindowTaskArn]
    def serviceRoleArn: Optional[ServiceRole]
    def taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]]
    def taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ]
    def priority: Optional[MaintenanceWindowTaskPriority]
    def maxConcurrency: Optional[MaxConcurrency]
    def maxErrors: Optional[MaxErrors]
    def loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo.ReadOnly]
    def name: Optional[MaintenanceWindowName]
    def description: Optional[MaintenanceWindowDescription]
    def replace: Optional[Boolean]
    def cutoffBehavior
        : Optional[zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior]
    def alarmConfiguration
        : Optional[zio.aws.ssm.model.AlarmConfiguration.ReadOnly]
    def getWindowId: ZIO[Any, Nothing, MaintenanceWindowId] =
      ZIO.succeed(windowId)
    def getWindowTaskId: ZIO[Any, Nothing, MaintenanceWindowTaskId] =
      ZIO.succeed(windowTaskId)
    def getTargets
        : ZIO[Any, AwsError, List[zio.aws.ssm.model.Target.ReadOnly]] =
      AwsError.unwrapOptionField("targets", targets)
    def getTaskArn: ZIO[Any, AwsError, MaintenanceWindowTaskArn] =
      AwsError.unwrapOptionField("taskArn", taskArn)
    def getServiceRoleArn: ZIO[Any, AwsError, ServiceRole] =
      AwsError.unwrapOptionField("serviceRoleArn", serviceRoleArn)
    def getTaskParameters: ZIO[Any, AwsError, Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]] = AwsError.unwrapOptionField("taskParameters", taskParameters)
    def getTaskInvocationParameters: ZIO[
      Any,
      AwsError,
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ] = AwsError.unwrapOptionField(
      "taskInvocationParameters",
      taskInvocationParameters
    )
    def getPriority: ZIO[Any, AwsError, MaintenanceWindowTaskPriority] =
      AwsError.unwrapOptionField("priority", priority)
    def getMaxConcurrency: ZIO[Any, AwsError, MaxConcurrency] =
      AwsError.unwrapOptionField("maxConcurrency", maxConcurrency)
    def getMaxErrors: ZIO[Any, AwsError, MaxErrors] =
      AwsError.unwrapOptionField("maxErrors", maxErrors)
    def getLoggingInfo
        : ZIO[Any, AwsError, zio.aws.ssm.model.LoggingInfo.ReadOnly] =
      AwsError.unwrapOptionField("loggingInfo", loggingInfo)
    def getName: ZIO[Any, AwsError, MaintenanceWindowName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, MaintenanceWindowDescription] =
      AwsError.unwrapOptionField("description", description)
    def getReplace: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("replace", replace)
    def getCutoffBehavior: ZIO[
      Any,
      AwsError,
      zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior
    ] = AwsError.unwrapOptionField("cutoffBehavior", cutoffBehavior)
    def getAlarmConfiguration
        : ZIO[Any, AwsError, zio.aws.ssm.model.AlarmConfiguration.ReadOnly] =
      AwsError.unwrapOptionField("alarmConfiguration", alarmConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ) extends zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly {
    override val windowId: MaintenanceWindowId =
      zio.aws.ssm.model.primitives.MaintenanceWindowId(impl.windowId())
    override val windowTaskId: MaintenanceWindowTaskId =
      zio.aws.ssm.model.primitives.MaintenanceWindowTaskId(impl.windowTaskId())
    override val targets: Optional[List[zio.aws.ssm.model.Target.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.Target.wrap(item)
          }.toList
        )
    override val taskArn: Optional[MaintenanceWindowTaskArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.taskArn())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowTaskArn(value)
        )
    override val serviceRoleArn: Optional[ServiceRole] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceRoleArn())
      .map(value => zio.aws.ssm.model.primitives.ServiceRole(value))
    override val taskParameters: Optional[Map[
      MaintenanceWindowTaskParameterName,
      zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.taskParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.ssm.model.primitives.MaintenanceWindowTaskParameterName(
              key
            ) -> zio.aws.ssm.model.MaintenanceWindowTaskParameterValueExpression
              .wrap(value)
          })
          .toMap
      )
    override val taskInvocationParameters: Optional[
      zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.taskInvocationParameters())
      .map(value =>
        zio.aws.ssm.model.MaintenanceWindowTaskInvocationParameters.wrap(value)
      )
    override val priority: Optional[MaintenanceWindowTaskPriority] =
      zio.aws.core.internal
        .optionalFromNullable(impl.priority())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowTaskPriority(value)
        )
    override val maxConcurrency: Optional[MaxConcurrency] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxConcurrency())
        .map(value => zio.aws.ssm.model.primitives.MaxConcurrency(value))
    override val maxErrors: Optional[MaxErrors] = zio.aws.core.internal
      .optionalFromNullable(impl.maxErrors())
      .map(value => zio.aws.ssm.model.primitives.MaxErrors(value))
    override val loggingInfo: Optional[zio.aws.ssm.model.LoggingInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loggingInfo())
        .map(value => zio.aws.ssm.model.LoggingInfo.wrap(value))
    override val name: Optional[MaintenanceWindowName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.ssm.model.primitives.MaintenanceWindowName(value))
    override val description: Optional[MaintenanceWindowDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowDescription(value)
        )
    override val replace: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.replace())
      .map(value => value: Boolean)
    override val cutoffBehavior
        : Optional[zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cutoffBehavior())
        .map(value =>
          zio.aws.ssm.model.MaintenanceWindowTaskCutoffBehavior.wrap(value)
        )
    override val alarmConfiguration
        : Optional[zio.aws.ssm.model.AlarmConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.alarmConfiguration())
        .map(value => zio.aws.ssm.model.AlarmConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.UpdateMaintenanceWindowTaskRequest
  ): zio.aws.ssm.model.UpdateMaintenanceWindowTaskRequest.ReadOnly =
    new Wrapper(impl)
}
